==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebRowToggleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowToggleEventArgsDetailDescriptionMetadata } from "./WebRowToggleEventArgsDetailDescriptionMetadata";
import { WebRowToggleEventArgsDescription } from "./WebRowToggleEventArgsDescription";
/**
 * @hidden
 */
var WebRowToggleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowToggleEventArgsDescriptionMetadata, _super);
    function WebRowToggleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowToggleEventArgsDescriptionMetadata.b = function (a) {
        if (WebRowToggleEventArgsDescriptionMetadata.a == null) {
            WebRowToggleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowToggleEventArgsDescriptionMetadata.c(WebRowToggleEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebRowToggleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRowToggleEventArgsDescriptionMetadata.a);
        WebRowToggleEventArgsDetailDescriptionMetadata.d(a);
    };
    WebRowToggleEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowToggleEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebRowToggleEventArgsDetail");
    };
    WebRowToggleEventArgsDescriptionMetadata.d = function (a) {
        WebRowToggleEventArgsDescriptionMetadata.b(a);
        a.aa("WebRowToggleEventArgs", function () { return new WebRowToggleEventArgsDescription(); });
        a.z("WebRowToggleEventArgs", WebRowToggleEventArgsDescriptionMetadata.a);
    };
    WebRowToggleEventArgsDescriptionMetadata.$t = markType(WebRowToggleEventArgsDescriptionMetadata, 'WebRowToggleEventArgsDescriptionMetadata');
    WebRowToggleEventArgsDescriptionMetadata.a = null;
    return WebRowToggleEventArgsDescriptionMetadata;
}(Base));
export { WebRowToggleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebRowToggleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowToggleEventArgsDetailDescriptionMetadata } from "./WebRowToggleEventArgsDetailDescriptionMetadata";
import { WebRowToggleEventArgsDescription } from "./WebRowToggleEventArgsDescription";
/**
 * @hidden
 */
var WebRowToggleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowToggleEventArgsDescriptionMetadata, _super);
    function WebRowToggleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowToggleEventArgsDescriptionMetadata.b = function (a) {
        if (WebRowToggleEventArgsDescriptionMetadata.a == null) {
            WebRowToggleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowToggleEventArgsDescriptionMetadata.c(WebRowToggleEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebRowToggleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRowToggleEventArgsDescriptionMetadata.a);
        WebRowToggleEventArgsDetailDescriptionMetadata.d(a);
    };
    WebRowToggleEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RowToggleEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebRowToggleEventArgsDetail");
    };
    WebRowToggleEventArgsDescriptionMetadata.d = function (a) {
        WebRowToggleEventArgsDescriptionMetadata.b(a);
        a.ac("WebRowToggleEventArgs", function () { return new WebRowToggleEventArgsDescription(); });
        a.ab("WebRowToggleEventArgs", WebRowToggleEventArgsDescriptionMetadata.a);
    };
    WebRowToggleEventArgsDescriptionMetadata.$t = markType(WebRowToggleEventArgsDescriptionMetadata, 'WebRowToggleEventArgsDescriptionMetadata');
    WebRowToggleEventArgsDescriptionMetadata.a = null;
    return WebRowToggleEventArgsDescriptionMetadata;
}(Base));
export { WebRowToggleEventArgsDescriptionMetadata };
